Argeus [1]_, son of Pelops and Hippodamia, by Hegesandra father of
Alector and Boethoos. [`wiki <https://en.wikipedia.org/wiki/Argeus>`__]

.. [1]
   Again, not an icon of the "real" Argeus. It is a picture used in the
   context of Argeus I of Macedon
   `wiki <https://en.wikipedia.org/wiki/Argaeus_I_of_Macedon#/media/File:Fragment_Maenad_Louvre_G160.jpg>`__.

